==> pDESy-0.3.4.tar.gz: pDESy-0.3.4/README.md <==
# pDESy: Discrete-Event Simulator in Python

![test](https://github.com/pDESy/pDESy/workflows/test/badge.svg)
[![codecov](https://codecov.io/gh/pDESy/pDESy/branch/master/graph/badge.svg)](https://codecov.io/gh/pDESy/pDESy)

## What is it?

**pDESy** is a Python package of Discrete-Event Simulator (DES). It aims to be the fundamental high-level building block for doing practical, real world engineering project management by using DES and other DES modeling tools. **pDESy** has only the function of discrete-event simulation, does not include the function of visual modeling.


## Where to get it
The source code is currently hosted on GitHub at: [https://github.com/pDESy/pDESy](https://github.com/pDESy/pDESy)

Binary installers for the latest released version will be available at the Python package index. Now, please install pDESy as following.

```sh
pip install pDESy
# pip install git+ssh://git@github.com/pDESy/pDESy.git # INSTALL FROM GITHUB
```

## License
[MIT](https://github.com/pDESy/pDESy/blob/master/LICENSE)

## Documentation
API Documentation is [https://pDESy.github.io/pDESy/index.html](https://pDESy.github.io/pDESy/index.html).

## Background
**pDESy** is developed by a part of next generation DES tool of **[pDES](https://github.com/pDESy/pDES)**.

## Contribution
1. Fork it ( http://github.com/pDESy/pDESy/fork )
2. Create your feature branch (git checkout -b my-new-feature)
3. Commit your changes (git commit -am 'Add some feature')
4. Push to the branch (git push origin my-new-feature)
5. Create new Pull Request

If you want to join this project as a researcher, please contact [me](https://github.com/taiga4112).

==> pDESy-0.4.0.tar.gz: pDESy-0.4.0/README.md <==
# pDESy: Discrete-Event Simulator in Python

[![PyPi version](https://pypip.in/v/pDESy/badge.png)](https://pypi.org/project/pDESy/)
[![Anaconda-Server Badge](https://anaconda.org/taiga4112/pdesy/badges/version.svg)](https://anaconda.org/taiga4112/pdesy)
![test](https://github.com/pDESy/pDESy/workflows/test/badge.svg)
[![codecov](https://codecov.io/gh/pDESy/pDESy/branch/master/graph/badge.svg)](https://codecov.io/gh/pDESy/pDESy)

## What is it?

**pDESy** is a Python package of Discrete-Event Simulator (DES). It aims to be the fundamental high-level building block for doing practical, real world engineering project management by using DES and other DES modeling tools. **pDESy** has only the function of discrete-event simulation, does not include the function of visual modeling.


## Where to get it
The source code is currently hosted on GitHub at: [https://github.com/pDESy/pDESy](https://github.com/pDESy/pDESy)

Binary installers for the latest released version will be available at the Python package index. Now, please install pDESy as following.

```sh
pip install pDESy
# pip install git+ssh://git@github.com/pDESy/pDESy.git # INSTALL FROM GITHUB
# conda install -c conda-forge -c taiga4112 pDESy # INSTALL FROM ANACONDA
```

## License
[MIT](https://github.com/pDESy/pDESy/blob/master/LICENSE)

## Documentation
API Documentation is [https://pDESy.github.io/pDESy/index.html](https://pDESy.github.io/pDESy/index.html).

## Background
**pDESy** is developed by a part of next generation DES tool of **[pDES](https://github.com/pDESy/pDES)**.

## Contribution
1. Fork it ( http://github.com/pDESy/pDESy/fork )
2. Create your feature branch (git checkout -b my-new-feature)
3. Commit your changes (git commit -am 'Add some feature')
4. Push to the branch (git push origin my-new-feature)
5. Create new Pull Request

If you want to join this project as a researcher, please contact [me](https://github.com/taiga4112).
